lcvtoolbox.vision.encoding.image.encode\_image\_lossy\_bytes
============================================================

.. currentmodule:: lcvtoolbox.vision.encoding.image

.. autofunction:: encode_image_lossy_bytes